rule

package
v0.0.0-...-4a841be Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 26, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

Package rule defines utility functions some revive rules can share.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CommonInitialisms

func CommonInitialisms() map[string]bool

CommonInitialisms returns the set of default initialisms used for name checks.

func Name

func Name(name string, allowlist, blocklist []string, skipInitialismNameChecks bool) (should string)

Name returns a different name of struct, var, const, or function if it should be different.

Types

This section is empty.

Jump to